@@ -1,29 +1,29 @@
 // KDE includes
 
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
+#include <tdecmdlineargs.h>
+#include <tdeaboutdata.h>
 #include <kuniqueapplication.h>
 
 #include "app.h"
 
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
 {
-    KCmdLineLastOption
+    TDECmdLineLastOption
 };
 
 int main(int argc, char *argv[])
 {
 
-    KLocale::setMainCatalogue("adept_installer");
+    TDELocale::setMainCatalogue("adept_installer");
 
     putenv( "TQT_IM_MODULE=xim" );
     TQString description = i18n("Adept Installer");
 
-    KAboutData aboutData( "adept_installer",
+    TDEAboutData aboutData( "adept_installer",
                           I18N_NOOP("Adept Installer"),
                           "2.1 Cruiser",
                           description.latin1(),
-                          KAboutData::License_BSD,
+                          TDEAboutData::License_BSD,
                           I18N_NOOP("(c) 2005, 2006 Peter Rockai"),
                           0,
                           "http://web.mornfall.net/adept.html");
@@ -33,14 +33,14 @@ int main(int argc, char *argv[])
                           "me at mornfall dot net",
                           "http://web.mornfall.net");
 
-    KCmdLineArgs::init( argc, argv, &aboutData );
-    KCmdLineArgs::addCmdLineOptions( options );
+    TDECmdLineArgs::init( argc, argv, &aboutData );
+    TDECmdLineArgs::addCmdLineOptions( options );
 
-    KApplication app;
+    TDEApplication app;
 
-    KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
+    TDECmdLineArgs* args = TDECmdLineArgs::parsedArgs();
 
-    KGlobal::locale()->insertCatalogue(TQString::fromUtf8("libept"));
+    TDEGlobal::locale()->insertCatalogue(TQString::fromUtf8("libept"));
 
     App *ta = new App();
 
